@@ -184,10 +184,15 @@ MODEL_CONFIGS = [
         default_image_size=512,
     ),
     ModelConfig(
-        short_name="ModernBuildings_SD21",
-        # config_path="configs/stable-diffusion-v2-inference-v.yaml",
-        config_path="configs/stable-diffusion-v2-modern-buildings.yaml",
-        weights_url="https://huggingface.co/smereces/2.1-SD-Modern-Buildings-Style-MD/resolve/main/midjourneyi_16500_lora.ckpt",
+        short_name="Art-Diffusion",
+        config_path="configs/stable-diffusion-v1.yaml",
+        weights_url="https://huggingface.co/DGSpitzer/DGSpitzer-Art-Diffusion/resolve/main/DGSpitzer-Art-Diffusion.ckpt",
+        default_image_size=512,
+    ),
+    ModelConfig(
+        short_name="graphic-art",
+        config_path="configs/graphicArt_graphicArtBeta.yaml",
+        weights_url="https://civitai.com/api/download/models/9297?type=Model&format=PickleTensor",
         default_image_size=768,
     ),
     ModelConfig(
