@@ -198,15 +198,13 @@ class ImaginePrompt:
         self.negative_prompt = self.process_prompt_input(self.negative_prompt)
 
         if self.model == "SD-2.0-v" and self.sampler_type == SamplerName.PLMS:
-            raise ValueError("PLMS sampler is not supported for SD-2.0-v model.")
+            self.sampler_type = SamplerName.K_EULER_ANCESTRAL
 
         if self.model == "edit" and self.sampler_type in (
             SamplerName.PLMS,
             SamplerName.DDIM,
         ):
-            raise ValueError(
-                "PLMS and DDIM samplers are not supported for pix2pix edit model."
-            )
+            self.sampler_type = SamplerName.K_EULER_ANCESTRAL
 
     @property
     def prompt_text(self):
